==> kmymoney-5.1.95.tar.xz: kmymoney-5.1.95/kmymoney/plugins/csv/import/csvimporter.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "aganders93@gmail.com,lukasz.wojnilowicz@gmail.com",
                "Name": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[ca@valencia]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[ca]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[cs]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[de]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[en_GB]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[eo]": "Allan Anderson, Łukasz Wojniłowicz",
                "Name[es]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[et]": "Allan Anderson, Łukasz Wojniłowicz",
                "Name[eu]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[fi]": "Allan Anderson, Łukasz Wojniłowicz",
                "Name[fr]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[gl]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[ia]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[it]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[ka]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[ko]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[nb]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[nl]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[pl]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[pt]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[pt_BR]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[ru]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[sk]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[sl]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[sv]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[tr]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[uk]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[x-test]": "xxAllan Anderson,Łukasz Wojniłowiczxx",
                "Name[zh_CN]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[zh_TW]": "Allan Anderson、Łukasz Wojniłowicz"
            }
        ],
        "Description": "Add CSV importing to KMyMoney",
        "Description[ca@valencia]": "Afig la importació des de CSV a KMyMoney",
        "Description[ca]": "Afegeix la importació des de CSV al KMyMoney",
        "Description[de]": "Fügt CSV-Import zu KMyMoney hinzu",
        "Description[en_GB]": "Add CSV importing to KMyMoney",
        "Description[eo]": "Aldoni CSV-importadon al KMyMoney",
        "Description[es]": "Añade importación CSV a KMyMoney",
        "Description[et]": "KMyMoney CVS importimine",
        "Description[eu]": "CSV inportazioa gehitzen dio KMyMoneyri ",
        "Description[fi]": "Lisää CSV-tuonti KMyMoney-ohjelmaan",
        "Description[fr]": "Ajoute l'importation « CSV » à KMyMoney",
        "Description[gl]": "Engadir a posibilidade de importar CSV en KMyMoney",
        "Description[it]": "Aggiunge l'importazione CSV a KMymoney",
        "Description[ka]": "KMyMoney-ში CSV შემოტანის დამატება",
        "Description[ko]": "KMyMoney에 CSV 가져오기 추가",
        "Description[nb]": "Legge til import av CSV i KMyMoney",
        "Description[nl]": "Voeg CSV importeren toe aan KMyMoney",
        "Description[pl]": "Dodaje importowanie CSV do KMyMoney",
        "Description[pt]": "Adição da importação de CSV para o KMyMoney",
        "Description[pt_BR]": "Adiciona importação CSV no KMyMoney",
        "Description[ru]": "Добавляет в KMyMoney возможность импорта CSV",
        "Description[sk]": "Pridať CSV importovanie do KMyMoney",
        "Description[sl]": "Doda uvoz CSV v KMyMoney",
        "Description[sv]": "Lägg till CSV-import till KMyMoney",
        "Description[tr]": "K Param'a CSV içe aktarma ekle",
        "Description[uk]": "Імпортування даних CSV у KMyMoney",
        "Description[x-test]": "xxAdd CSV importing to KMyMoneyxx",
        "Description[zh_CN]": "为 KMyMoney 添加 CSV 导入服务",
        "Description[zh_TW]": "提供 CSV 匯入功能給 KMyMoney",
        "EnabledByDefault": true,
        "Icon": "document-import",
        "Id": "csvimporter",
        "License": "GPL",
        "Name": "CSV Importer",
        "Name[ca@valencia]": "Importador de CSV",
        "Name[ca]": "Importador de CSV",
        "Name[cs]": "Importér CSV",
        "Name[de]": "CSV-Import",
        "Name[en_GB]": "CSV Importer",
        "Name[eo]": "CSV Importilo",
        "Name[es]": "Importador CSV",
        "Name[et]": "CVS importija",
        "Name[eu]": "CSV-inportatzailea",
        "Name[fi]": "CSV-tuoja",
        "Name[fr]": "Importateur CSV",
        "Name[gl]": "Importador de CSV",
        "Name[ia]": "Importator de CSV",
        "Name[it]": "Strumento di importazione CSV",
        "Name[ka]": "CSV შემომტანი",
        "Name[ko]": "CSV 가져오기 도구",
        "Name[nb]": "CSV-import",
        "Name[nl]": "CSV-importprogramma",
        "Name[pl]": "Importer CSV",
        "Name[pt]": "Importação de CSV",
        "Name[pt_BR]": "Importador CSV",
        "Name[ru]": "Импорт CSV",
        "Name[sk]": "Importér CSV",
        "Name[sl]": "Uvoznik CSV",
        "Name[sv]": "CSV-import",
        "Name[tr]": "CSV İçe Aktarıcısı",
        "Name[uk]": "Імпортування CSV",
        "Name[x-test]": "xxCSV Importerxx",
        "Name[zh_CN]": "CSV 导入工具",
        "Name[zh_TW]": "CSV 匯入工具",
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    },
    "X-KDE-ConfigModule": "kmymoney_plugins/kcms/kcm_csvimporter"
}

==> kmymoney-5.2.0.tar.xz: kmymoney-5.2.0/kmymoney/plugins/csv/import/csvimporter.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "aganders93@gmail.com,lukasz.wojnilowicz@gmail.com",
                "Name": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[ca@valencia]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[ca]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[cs]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[de]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[en_GB]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[eo]": "Allan Anderson, Łukasz Wojniłowicz",
                "Name[es]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[et]": "Allan Anderson, Łukasz Wojniłowicz",
                "Name[eu]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[fi]": "Allan Anderson, Łukasz Wojniłowicz",
                "Name[fr]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[gl]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[ia]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[it]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[ka]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[ko]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[nb]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[nl]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[pl]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[pt]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[pt_BR]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[ru]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[sk]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[sl]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[sv]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[uk]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[x-test]": "xxAllan Anderson,Łukasz Wojniłowiczxx",
                "Name[zh_CN]": "Allan Anderson,Łukasz Wojniłowicz",
                "Name[zh_TW]": "Allan Anderson、Łukasz Wojniłowicz"
            }
        ],
        "Description": "Add CSV importing to KMyMoney",
        "Description[ca@valencia]": "Afig la importació des de CSV a KMyMoney",
        "Description[ca]": "Afegeix la importació des de CSV al KMyMoney",
        "Description[de]": "Fügt CSV-Import zu KMyMoney hinzu",
        "Description[en_GB]": "Add CSV importing to KMyMoney",
        "Description[eo]": "Aldoni CSV-importadon al KMyMoney",
        "Description[es]": "Añade importación CSV a KMyMoney",
        "Description[et]": "KMyMoney CVS importimine",
        "Description[eu]": "CSV inportazioa gehitzen dio KMyMoneyri ",
        "Description[fi]": "Lisää CSV-tuonti KMyMoney-ohjelmaan",
        "Description[fr]": "Ajoute l'importation « CSV » à KMyMoney",
        "Description[gl]": "Engadir a posibilidade de importar CSV en KMyMoney",
        "Description[ia]": "Adde importar de CSV a KMyMoney",
        "Description[it]": "Aggiunge l'importazione CSV a KMymoney",
        "Description[ka]": "KMyMoney-ში CSV შემოტანის დამატება",
        "Description[ko]": "KMyMoney에 CSV 가져오기 추가",
        "Description[nb]": "Legge til import av CSV i KMyMoney",
        "Description[nl]": "Voeg CSV importeren toe aan KMyMoney",
        "Description[pl]": "Dodaje importowanie CSV do KMyMoney",
        "Description[pt]": "Adição da importação de CSV para o KMyMoney",
        "Description[pt_BR]": "Adiciona importação CSV no KMyMoney",
        "Description[ru]": "Добавляет в KMyMoney возможность импорта CSV",
        "Description[sk]": "Pridať CSV importovanie do KMyMoney",
        "Description[sl]": "Doda uvoz CSV v KMyMoney",
        "Description[sv]": "Lägg till CSV-import till KMyMoney",
        "Description[uk]": "Імпортування даних CSV у KMyMoney",
        "Description[x-test]": "xxAdd CSV importing to KMyMoneyxx",
        "Description[zh_CN]": "为 KMyMoney 添加 CSV 导入服务",
        "Description[zh_TW]": "提供 CSV 匯入功能給 KMyMoney",
        "EnabledByDefault": true,
        "Icon": "document-import",
        "Id": "csvimporter",
        "License": "GPL",
        "Name": "CSV Importer",
        "Name[ca@valencia]": "Importador de CSV",
        "Name[ca]": "Importador de CSV",
        "Name[cs]": "Importér CSV",
        "Name[de]": "CSV-Import",
        "Name[en_GB]": "CSV Importer",
        "Name[eo]": "CSV Importilo",
        "Name[es]": "Importador CSV",
        "Name[et]": "CVS importija",
        "Name[eu]": "CSV-inportatzailea",
        "Name[fi]": "CSV-tuoja",
        "Name[fr]": "Importateur CSV",
        "Name[gl]": "Importador de CSV",
        "Name[ia]": "Importator de CSV",
        "Name[it]": "Strumento di importazione CSV",
        "Name[ka]": "CSV შემომტანი",
        "Name[ko]": "CSV 가져오기 도구",
        "Name[nb]": "CSV-import",
        "Name[nl]": "CSV-importprogramma",
        "Name[pl]": "Importer CSV",
        "Name[pt]": "Importação de CSV",
        "Name[pt_BR]": "Importador CSV",
        "Name[ru]": "Импорт CSV",
        "Name[sk]": "Importér CSV",
        "Name[sl]": "Uvoznik CSV",
        "Name[sv]": "CSV-import",
        "Name[uk]": "Імпортування CSV",
        "Name[x-test]": "xxCSV Importerxx",
        "Name[zh_CN]": "CSV 导入工具",
        "Name[zh_TW]": "CSV 匯入工具",
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    },
    "X-KDE-ConfigModule": "kmymoney_plugins/kcms/kcm_csvimporter"
}
